// BaseView.cpp
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//
//
#include <Debug.h>

#include "BaseView.h"

// for archiving
static const char CLASS_NAME[] = "BaseView";
static const char MIN_NAME[] = "BaseView::min";
static const char MAX_NAME[] = "BaseView::max";

// Public: Constructor.
//
BaseView::BaseView(BRect frame, const char *name,
			 	   uint32 resizingMode, uint32 flags,
		   const BRect &minimum, const BRect &maximum)
	: BView(frame, name, resizingMode, flags), min(minimum), max(maximum) {}

// Public: Constructopr from the archive.
//
BaseView::BaseView(BMessage *archive)
	: BView(archive) {
	status_t ret;
	ret = archive->FindRect(MIN_NAME, &min);
	ASSERT(ret == B_OK);

	ret = archive->FindRect(MAX_NAME, &max);
	ASSERT(ret == B_OK);
}

// Public: Destructor.
//
BaseView::~BaseView() {}

// Public: Archive the object.
//
status_t
BaseView::Archive(BMessage *archive, bool deep) const {
	status_t ret;
	ret = BView::Archive(archive, deep);
	ASSERT(ret == B_OK);

	ret = archive->AddString("class", CLASS_NAME);
	ASSERT(ret == B_OK);

	if ( deep ) { 
		ret = archive->AddRect(MIN_NAME, min);
		ASSERT(ret == B_OK);

		ret = archive->AddRect(MAX_NAME, max);
		ASSERT(ret == B_OK);
	}

	return B_OK;
}

// Public/Static: Instanciate from the archive.
//
BArchivable *
BaseView::Instantiate(BMessage *archive) {
	if (validate_instantiation(archive, CLASS_NAME))
		return new BaseView(archive);
	
	return NULL; 
}

// Private: Copy Constructor.
//
BaseView::BaseView(const BaseView &src)
	: BView(src.Bounds(), "BaseView_dummy", B_FOLLOW_ALL, B_WILL_DRAW),
	  min(src.min), max(src.max) {}

// Private:
//
BaseView &
BaseView::operator=(const BaseView &src) {
	min = src.min;
	max = src.max;
	
	return *this;
}

