// BaseView.h
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//
//

#ifndef _BASE_VIEW_H_
#define _BASE_VIEW_H_

#include <Rect.h>
#include <View.h>
#include <Message.h>

// This class is the base class for a view that has minimum&maximum
// limitation in its size.
//
class _EXPORT BaseView : public BView {
public:
	BaseView(BRect frame, const char *name,
			 uint32 resizingMode, uint32 flags,
		 const BRect &minimum, const BRect &maximum);
	BaseView(BMessage *archive);
	virtual ~BaseView();
	
	inline const BRect &GetMinSize() const { return min; };
	inline const BRect &GetMaxSize() const { return max; };
	inline void SetMinSize(const BRect &rect) { min = rect; };
	inline void SetMaxSize(const BRect &rect) { max = rect; };

	// Archivable
	status_t Archive(BMessage *archive, bool deep) const;
	static BArchivable *Instantiate(BMessage *archive);
	
private:
	BaseView(const BaseView &);
	BaseView &operator=(const BaseView &);
	
	BRect min, max;
};

#endif /* _BASE_VIEW_H_ */
