// SysInfoDeltaGenerator.cpp
// Copyright(C) 1999 by Kiyoshi Kobayashi. All rights reserved.
//

// System headers
#include <List.h>
#include <Autolock.h>
#include <Debug.h>

// Local headers
#include "SysInfoDeltaGenerator.h"

// ListIterator private class
class ListIterator {
  public:
	ListIterator(BList &orig) : list(orig), pos(0) {};
	~ListIterator() {};
	void *GetNext() {
		void *ret = NULL;
		if (pos < list.CountItems())
			ret = list.ItemAt(pos++);
		return ret;
	};
	
  private:
	BList &list;
	int32 pos;
};

// To keep the pointer to the singleton object.
SysInfoDeltaGenerator *
SysInfoDeltaGenerator::gen;

// This lock is supposed to be initialized before any method
// in this class get called.
BLocker
SysInfoDeltaGenerator::genLock;

// Instance accessor
SysInfoDeltaGenerator *
SysInfoDeltaGenerator::GetGenerator() {
	BAutolock l(genLock);
	ASSERT((l.IsLocked()));
	if (gen == NULL) { // Instanciate the singleton object.
		gen = new SysInfoDeltaGenerator();
	}
	return gen;
}

// Constructor
SysInfoDeltaGenerator::SysInfoDeltaGenerator() {
}

// Destructor
SysInfoDeltaGenerator::~SysInfoDeltaGenerator() {
}

// Public functions
bool
SysInfoDeltaGenerator::Register(SysInfoObserver *obs) {
	bool ret = true;
	BAutolock l(lock);
	ASSERT((l.IsLocked()));
	
	if (!list.HasItem(obs))
		ret = list.AddItem((void *)obs);
	// else ignore duplicated call
	return ret;
}

bool
SysInfoDeltaGenerator::Unregister(SysInfoObserver *obs) {
	bool ret = true;
	BAutolock l(lock);
	ASSERT((l.IsLocked()));
	
	if (list.HasItem(obs))
		ret = list.RemoveItem((void *)obs);
	// else ignore duplicated call
	return ret;
}

void
SysInfoDeltaGenerator::Generate() {
	BAutolock l(lock);
	ASSERT((l.IsLocked()));
	
	SysInfo cur;
	SysInfo updated = pre - cur;
	pre = cur;
	
	ListIterator iter(list);
	void *obs = NULL;
	while((obs = iter.GetNext()) != NULL) {
		((SysInfoObserver *)obs)->Updated(updated);
	}
}

